import React,{Component} from 'react';
import {View,Icon} from '@tarojs/components'
import {getUserByName} from '../../utils/servers/servers';

import {AtSearchBar, AtPagination} from 'taro-ui'

import 'taro-ui/dist/style/components/search-bar.scss';
import 'taro-ui/dist/style/components/button.scss';
import 'taro-ui/dist/style/components/list.scss';
import 'taro-ui/dist/style/components/icon.scss';
import 'taro-ui/dist/style/components/pagination.scss';

import ListBottomStart from '../../components/common/listBottomStart';

import Taro from '@tarojs/taro';

class Enterprise extends Component{
  constructor(props) {
    super(props);
    this.state={
      value:'',
      list:[],
      listState:'NO_DATA',
      selectId:0,
      pageNo:1
    }
    this.onChange = this.onChange.bind(this);
  }

  onChange (value,lv=true) {
    this.setState({
      value,
    })
    if(value.length < 2 && !lv){
      Taro.showToast({title:'最少输入两个字符',icon:'none'})
      return
    }
    if(value.length < 4 && lv){return}
    this.getList(value)
  }

  componentWillUnmount() {
    this.setState({
      value:'',
      list:[],
      listState:'NO_DATA',
      selectId:0,
      pageNo:1,
      totalCount:0
    })
  }

  getList(value = this.state.value,pageNo = 1){
    Taro.showLoading({title:'加载中...'})
    this.setState({
      listState: 'LOADING'
    })
    getUserByName({
      name:value,
      pageNo: pageNo,
      pageSize: 10,
    }).then((msg)=>{
      Taro.hideLoading();
      if(msg.error.length === 0){
        if(msg.data.totalCount === 0){
          this.setState({
            listState: 'NO_DATA'
          })
        }else if(msg.data.totalCount === this.state.list.length && pageNo !== 1){
          Taro.showToast({title:'没有更多数据了',icon:'none'});
          this.setState({
            listState: 'NO_MORE_DATA'
          })
        }else{
          if(msg.data.totalCount === (pageNo === 1 ? msg.data.list : this.state.list.concat(msg.data.list)).length){
            this.setState({
              listState: 'NO_MORE_DATA'
            })
          }
        }
        this.setState({
          list:msg.data.list,
          pageNo: msg.data.pageNo,
          totalCount:msg.data.totalCount
        })
      }else{
        Taro.showToast({title:msg.error[0].message,icon:'none'});
        this.setState({
          listState: msg.error[0].field === '403' ? 'NO_DATA' : 'RELOAD'
        })
      }
    }).catch(()=>{
      Taro.hideLoading();
      this.setState({
        listState: 'RELOAD'
      })
    })
  }

  render() {
    return (
      <>
        <AtSearchBar
          showActionButton
          value={this.state.value}
          placeholder='请输入公出企业名称'
          onChange={this.onChange}
          onActionClick={()=>{this.onChange(this.state.value,false)}}
          onConfirm={()=>{this.onChange(this.state.value,false)}}
          onClear={()=>{
            this.setState({
              value:'',
              list:[],
              listState:'NO_DATA',
              selectId:0,
              pageNo:1,
              totalCount:0
            },()=>{
              this.props.onChange({});
            })
          }}
        />
        <View>
          {
            this.state.list.map((v,k)=>(
              <View style={{
                padding:'10px',
                display:'flex',
                flexFlow:'row',
                alignItems:'center',
                justifyContent:'space-between',
                borderBottom:'1px #ece6e6 solid'
              }} key={k} onClick={()=>{
                this.setState({
                  selectId:v.id
                })
                this.props.onChange({uid:v.id,nickname:v.name});
              }}>
                <View style={{fontSize:'15px'}}>{v.name}</View>
                {this.state.selectId === v.id ? <Icon size='20' type='success_no_circle' /> : null}
              </View>
            ))
          }
          <ListBottomStart
            type='pagination'
            pageSize={10}
            state={this.state.listState}
            total={this.state.totalCount}
            current={this.state.pageNo}
            onPageChange={(type, current)=>{
              this.getList(this.state.value,current);
            }}
            reload={()=>{
              this.getList(this.state.value);
            }}
          />
        </View>
      </>
    )
  }
}

export default Enterprise;
